@@ -412,22 +412,22 @@
       }
 
       Glyph.prototype.defaults = function() {
-        return {
+        return _.extend({}, Glyph.__super__.defaults.call(this), {
           x_range_name: "default",
           y_range_name: "default",
           data_source: null
-        };
+        });
       };
 
       Glyph.prototype.display_defaults = function() {
-        return {
+        return _.extend({}, Glyph.__super__.display_defaults.call(this), {
           level: 'glyph',
           radius_units: 'data',
           length_units: 'screen',
           angle_units: 'deg',
           start_angle_units: 'deg',
           end_angle_units: 'deg'
-        };
+        });
       };
 
       return Glyph;
