@@ -123,23 +123,17 @@ class TestDataSpec(unittest.TestCase):
         self.assertDictEqual(Foo.__dict__["x"].to_dict(f), {"value": 15, "units": "data"})
         f.x = dict(value=23, units="screen")
         self.assertDictEqual(Foo.__dict__["x"].to_dict(f), {"value": 23, "units": "screen"})
-        # Setting defaults when there is a fixed value should do nothing, so verify this.
-        # Also, setting a dict clobbers all fields that are not explicitly set, so "units"
-        # gets reset back to the default value on the DataSpec, which is "data".
-        f.x = dict(value=32, default=18)
+        f.x = dict(value=32)
         self.assertDictEqual(Foo.__dict__["x"].to_dict(f), {"value": 32, "units": "data"})
 
     def test_default(self):
         class Foo(HasProps):
-            y = DataSpec("yfield", default=12)
+            y = DataSpec(default=12)
         f = Foo()
-        self.assertEqual(f.y, {"field": "yfield", "default": 12})
-        self.assertDictEqual(Foo.__dict__["y"].to_dict(f), {"field": "yfield", "default": 12, "units": "data"})
+        self.assertEqual(f.y, 12)
+        self.assertDictEqual(Foo.__dict__["y"].to_dict(f), {"value": 12, "units": "data"})
         f.y = "y1"
         self.assertEqual(f.y, "y1")
-        f.y = ("y2", 27)
-        self.assertDictEqual(f.y, {"field": "y2", "default": 27, "units": "data"})
-        self.assertDictEqual(Foo.__dict__["y"].to_dict(f), {"field": "y2", "default": 27, "units": "data"})
         # Once we set a concrete value, the default is ignored, because it is unused
         f.y = 32
         self.assertEqual(f.y, 32)
@@ -157,12 +151,9 @@ class TestDataSpec(unittest.TestCase):
         self.assertEqual(b.x, 14)
         self.assertDictEqual(Foo.__dict__["x"].to_dict(a), {"value": 13, "units": "data"})
         self.assertDictEqual(Foo.__dict__["x"].to_dict(b), {"value": 14, "units": "data"})
-        a.x = ("x2", 21)
-        self.assertDictEqual(Foo.__dict__["x"].to_dict(a), {"field": "x2", "default": 21, "units": "data"})
-        self.assertDictEqual(Foo.__dict__["x"].to_dict(b), {"value": 14, "units": "data"})
-        b.x = {"field": "x3", "units": "screen", "default": 25}
-        self.assertDictEqual(Foo.__dict__["x"].to_dict(a), {"field": "x2", "default": 21, "units": "data"})
-        self.assertDictEqual(Foo.__dict__["x"].to_dict(b), {"field": "x3", "units": "screen", "default": 25})
+        b.x = {"field": "x3", "units": "screen"}
+        self.assertDictEqual(Foo.__dict__["x"].to_dict(a), {"value": 13, "units": "data"})
+        self.assertDictEqual(Foo.__dict__["x"].to_dict(b), {"field": "x3", "units": "screen"})
 
 
 class TestColorSpec(unittest.TestCase):
@@ -180,22 +171,22 @@ class TestColorSpec(unittest.TestCase):
 
     def test_field_default(self):
         class Foo(HasProps):
-            col = ColorSpec("colorfield", default="red")
+            col = ColorSpec(default="red")
         desc = Foo.__dict__["col"]
         f = Foo()
-        self.assertDictEqual(f.col, {"field": "colorfield", "default": "red"})
-        self.assertDictEqual(desc.to_dict(f), {"field": "colorfield", "default": "red"})
+        self.assertEqual(f.col, "red")
+        self.assertDictEqual(desc.to_dict(f), {"value": "red"})
         f.col = "myfield"
-        self.assertDictEqual(f.col, {"field": "myfield", "default": "red"})
-        self.assertDictEqual(desc.to_dict(f), {"field": "myfield", "default": "red"})
+        self.assertEqual(f.col, "myfield")
+        self.assertDictEqual(desc.to_dict(f), {"field": "myfield"})
 
     def test_default_tuple(self):
         class Foo(HasProps):
-            col = ColorSpec("colorfield", default=(128, 255, 124))
+            col = ColorSpec(default=(128, 255, 124))
         desc = Foo.__dict__["col"]
         f = Foo()
-        self.assertDictEqual(f.col, {"field": "colorfield", "default": (128, 255, 124)})
-        self.assertDictEqual(desc.to_dict(f), {"field": "colorfield", "default": "rgb(128, 255, 124)"})
+        self.assertEqual(f.col, (128, 255, 124))
+        self.assertDictEqual(desc.to_dict(f), {"value": "rgb(128, 255, 124)"})
 
     def test_fixed_value(self):
         class Foo(HasProps):
@@ -242,8 +233,8 @@ class TestColorSpec(unittest.TestCase):
         self.assertEqual(f.col, "forestgreen")
         self.assertDictEqual(desc.to_dict(f), {"value": "forestgreen"})
         f.col = "myfield"
-        self.assertDictEqual(f.col, {"field": "myfield", "default": "blue"})
-        self.assertDictEqual(desc.to_dict(f), {"field": "myfield", "default": "blue"})
+        self.assertEqual(f.col, "myfield")
+        self.assertDictEqual(desc.to_dict(f), {"field": "myfield"})
 
     def test_hex_value(self):
         class Foo(HasProps):
@@ -277,8 +268,8 @@ class TestColorSpec(unittest.TestCase):
             col = ColorSpec("colorfield")
         desc = Foo.__dict__["col"]
         f = Foo()
-        f.col = {"field": "myfield", "default": "#88FF00"}
-        self.assertDictEqual(f.col, {"field": "myfield", "default": "#88FF00"})
+        f.col = {"field": "myfield"}
+        self.assertDictEqual(f.col, {"field": "myfield"})
 
         f.col = "field2"
         self.assertEqual(f.col, "field2")
