@@ -14,7 +14,7 @@ inc = df.close > df.open
 dec = df.open > df.close
 w = 12*60*60*1000 # half day in ms
 
-output_file("candlestick.html", title="candlestick.py example", js="absolute", css="absolute")
+output_file("candlestick.html", title="candlestick.py example")
 
 figure(x_axis_type = "datetime", tools="pan,wheel_zoom,box_zoom,reset,previewsave",
        width=1000, name="candlestick")
