@@ -1,3 +1,5 @@
+# The plot server must be running
+# Go to http://localhost:5006/bokeh to view this plot
 
 import numpy as np
 from scipy.integrate import odeint
@@ -28,10 +30,10 @@ xprime = np.cos(theta) * x - np.sin(theta) * y
 
 colors = ["#C6DBEF", "#9ECAE1", "#6BAED6", "#4292C6", "#2171B5", "#08519C", "#08306B",]
 
-output_server("lorenz.py example")
+output_server("lorenz")
 
 multi_line(np.array_split(xprime, 7), np.array_split(z, 7),
            line_color=colors, line_alpha=0.8, line_width=1.5,
-           tools="pan,zoom,resize", title="lorenz example")
+           tools="pan,wheel_zoom,box_zoom,reset,previewsave", title="lorenz example")
 
 show()  # open a browser
